WindowAggregator

Struct WindowAggregator 

pub struct WindowAggregator<Key, AggInit, AggregatorImpl> { /* private fields */ }
A struct for window-based aggregation of time-series data.

The struct maintains a set of active windows per key and aggregates data within those windows per key. It also handles out-of-order data and late-arriving events.